@@ -3,6 +3,7 @@ package FreeBSD::Ports::INDEXhash;
 use warnings;
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+require Exporter;
 
 @EXPORT_OK   = qw(INDEXhash);
 @ISA         = qw(Exporter);
@@ -14,11 +15,11 @@ FreeBSD::Ports::INDEXhash - Generates a hash out of the FreeBSD Ports index file
 
 =head1 VERSION
 
-Version 1.2.0
+Version 1.2.2
 
 =cut
 
-our $VERSION = '1.1.0';
+our $VERSION = '1.2.2';
 
 
 =head1 SYNOPSIS
@@ -151,13 +152,14 @@ sub INDEXhash {
 		$depsInt=0;
 		my @Edeps=split(/ /, $linesplit[10]);
 		while(defined($Edeps[$depsInt])){
-			push(@{$hash{$linesplit[0]}{Edeps}}, $Pdeps[$depsInt]);
+			push(@{$hash{$linesplit[0]}{Edeps}}, $Edeps[$depsInt]);
 
 			$depsInt++;
 		};
 
+		$depsInt=0;
 		my @Rdeps=split(/ /, $linesplit[8]);
-		while(defined($Edeps[$depsInt])){
+		while(defined($Rdeps[$depsInt])){
 			push(@{$hash{$linesplit[0]}{Rdeps}}, $Rdeps[$depsInt]);
 
 			$depsInt++;
